# Task templates

The tasks supported by [`Dataset.prepare_for_task`] and [`DatasetDict.prepare_for_task`].

[[autodoc]] datasets.tasks.AutomaticSpeechRecognition

[[autodoc]] datasets.tasks.AudioClassification

[[autodoc]] datasets.tasks.ImageClassification
    - align_with_features

[[autodoc]] datasets.tasks.LanguageModeling

[[autodoc]] datasets.tasks.QuestionAnsweringExtractive

[[autodoc]] datasets.tasks.Summarization

[[autodoc]] datasets.tasks.TextClassification
    - align_with_features
